@@ -20,7 +20,7 @@ class MigrateManager:
                 self.models_directory = directory
 
             Migrate(app, db, compare_type=True)
-            self.directory = 'migrations-{}'.format(app.config.get('FLASK_ENV'))
+            self.directory = 'migrations'
             self.app = app
             self.db = db
             self.producer = producer
